# Sprocket
version 0.2.0

## Description
A simple discord bot for rolling dice.

## Installation
```bash
pip install sprocket-fizzlebang
```

## Running
```bash
python -m sprocket
```
or simply
```bash
sprocket
```

## Commands
```
!roll <expression>
!reroll
!reroll list
!reroll <selection>
```

### Examples
```
!roll 1d20 + 1d4 - 1
!roll 1d100
!roll 2d8 + 3 - 1d10

!reroll list
!reroll 2
```
